# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class InlineResponse2001RuntimeEnvironments(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'os_name': 'str',
        'os_version': 'str',
        'python_version': 'str'
    }

    attribute_map = {
        'os_name': 'os_name',
        'os_version': 'os_version',
        'python_version': 'python_version'
    }

    def __init__(self, os_name=None, os_version=None, python_version=None):  # noqa: E501
        """InlineResponse2001RuntimeEnvironments - a model defined in Swagger"""  # noqa: E501
        self._os_name = None
        self._os_version = None
        self._python_version = None
        self.discriminator = None
        self.os_name = os_name
        self.os_version = os_version
        self.python_version = python_version

    @property
    def os_name(self):
        """Gets the os_name of this InlineResponse2001RuntimeEnvironments.  # noqa: E501

        Name of the operating system which is supported.  # noqa: E501

        :return: The os_name of this InlineResponse2001RuntimeEnvironments.  # noqa: E501
        :rtype: str
        """
        return self._os_name

    @os_name.setter
    def os_name(self, os_name):
        """Sets the os_name of this InlineResponse2001RuntimeEnvironments.

        Name of the operating system which is supported.  # noqa: E501

        :param os_name: The os_name of this InlineResponse2001RuntimeEnvironments.  # noqa: E501
        :type: str
        """
        if os_name is None:
            raise ValueError("Invalid value for `os_name`, must not be `None`")  # noqa: E501

        self._os_name = os_name

    @property
    def os_version(self):
        """Gets the os_version of this InlineResponse2001RuntimeEnvironments.  # noqa: E501

        Version of the operating system which is supported.  # noqa: E501

        :return: The os_version of this InlineResponse2001RuntimeEnvironments.  # noqa: E501
        :rtype: str
        """
        return self._os_version

    @os_version.setter
    def os_version(self, os_version):
        """Sets the os_version of this InlineResponse2001RuntimeEnvironments.

        Version of the operating system which is supported.  # noqa: E501

        :param os_version: The os_version of this InlineResponse2001RuntimeEnvironments.  # noqa: E501
        :type: str
        """
        if os_version is None:
            raise ValueError("Invalid value for `os_version`, must not be `None`")  # noqa: E501

        self._os_version = os_version

    @property
    def python_version(self):
        """Gets the python_version of this InlineResponse2001RuntimeEnvironments.  # noqa: E501

        Supported Python version.  # noqa: E501

        :return: The python_version of this InlineResponse2001RuntimeEnvironments.  # noqa: E501
        :rtype: str
        """
        return self._python_version

    @python_version.setter
    def python_version(self, python_version):
        """Sets the python_version of this InlineResponse2001RuntimeEnvironments.

        Supported Python version.  # noqa: E501

        :param python_version: The python_version of this InlineResponse2001RuntimeEnvironments.  # noqa: E501
        :type: str
        """
        if python_version is None:
            raise ValueError("Invalid value for `python_version`, must not be `None`")  # noqa: E501

        self._python_version = python_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InlineResponse2001RuntimeEnvironments, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InlineResponse2001RuntimeEnvironments):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
