# coding: utf-8

"""
    Thoth User API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 0.6.0-dev
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class AnalysisUnfinishedResultResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'error': 'str',
        'parameters': 'object',
        'status': 'AnalysisStatusResponse'
    }

    attribute_map = {
        'error': 'error',
        'parameters': 'parameters',
        'status': 'status'
    }

    def __init__(self, error=None, parameters=None, status=None):  # noqa: E501
        """AnalysisUnfinishedResultResponse - a model defined in Swagger"""  # noqa: E501
        self._error = None
        self._parameters = None
        self._status = None
        self.discriminator = None
        self.error = error
        self.parameters = parameters
        self.status = status

    @property
    def error(self):
        """Gets the error of this AnalysisUnfinishedResultResponse.  # noqa: E501

        Error information for user.  # noqa: E501

        :return: The error of this AnalysisUnfinishedResultResponse.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this AnalysisUnfinishedResultResponse.

        Error information for user.  # noqa: E501

        :param error: The error of this AnalysisUnfinishedResultResponse.  # noqa: E501
        :type: str
        """
        if error is None:
            raise ValueError("Invalid value for `error`, must not be `None`")  # noqa: E501

        self._error = error

    @property
    def parameters(self):
        """Gets the parameters of this AnalysisUnfinishedResultResponse.  # noqa: E501

        Parameters echoed back to user for debugging.  # noqa: E501

        :return: The parameters of this AnalysisUnfinishedResultResponse.  # noqa: E501
        :rtype: object
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this AnalysisUnfinishedResultResponse.

        Parameters echoed back to user for debugging.  # noqa: E501

        :param parameters: The parameters of this AnalysisUnfinishedResultResponse.  # noqa: E501
        :type: object
        """
        if parameters is None:
            raise ValueError("Invalid value for `parameters`, must not be `None`")  # noqa: E501

        self._parameters = parameters

    @property
    def status(self):
        """Gets the status of this AnalysisUnfinishedResultResponse.  # noqa: E501


        :return: The status of this AnalysisUnfinishedResultResponse.  # noqa: E501
        :rtype: AnalysisStatusResponse
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this AnalysisUnfinishedResultResponse.


        :param status: The status of this AnalysisUnfinishedResultResponse.  # noqa: E501
        :type: AnalysisStatusResponse
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalysisUnfinishedResultResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalysisUnfinishedResultResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
